@@ -37,16 +37,24 @@ from adi.fmcomms5 import *
 
 from adi.ad9371 import *
 
+from adi.adrv9002 import adrv9002
+
 from adi.adrv9009 import *
 
 from adi.adrv9009_zu11eg import *
 
+from adi.adrv9009_zu11eg_multi import *
+
+from adi.adrv9009_zu11eg_fmcomms8 import *
+
 from adi.ad9680 import *
 
 from adi.ad9144 import *
 
 from adi.ad9152 import *
 
+from adi.cn0532 import *
+
 from adi.daq2 import *
 
 from adi.daq3 import *
@@ -61,9 +69,13 @@ from adi.adxl345 import *
 
 from adi.fmclidar1 import *
 
+from adi.jesd import *
+
 from adi.ad5686 import *
 
+from adi.adar1000 import adar1000
+
 from adi.ltc2983 import *
 
-__version__ = "0.0.5"
+__version__ = "0.0.6"
 name = "Analog Devices Hardware Interfaces"
